@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::AddressList;
-$Email::MIME::RFC2047::AddressList::VERSION = '0.94';
+$Email::MIME::RFC2047::AddressList::VERSION = '0.95';
 use strict;
 use warnings;
 
@@ -80,14 +80,14 @@ Email::MIME::RFC2047::AddressList - Handling of MIME encoded address lists
 
 =head1 VERSION
 
-version 0.94
+version 0.95
 
 =head1 SYNOPSIS
 
     use Email::MIME::RFC2047::AddressList;
 
     my $address_list = Email::MIME::RFC2047::AddressList->parse($string);
-    my @items = $address_list->items();
+    my @items = $address_list->items;
 
     my $address_list = Email::MIME::RFC2047::AddressList->new();
     $address_list->push($mailbox);
@@ -103,12 +103,14 @@ This module handles RFC 2822 C<address-list>s.
 =head2 parse
 
     my $address_list = Email::MIME::RFC2047::AddressList->parse(
-       $string, [$decoder]
+        $string, [$decoder]
     );
 
 Parse a RFC 2822 C<address-list>. Returns an
 Email::MIME::RFC2047::AddressList object containing
 L<Email::MIME::RFC2047::Address> items.
+C<$decoder> is an optional L<Email::MIME::RFC2047::Decoder>. If it isn't
+provided, a new temporary decoder is used.
 
 =head1 CONSTRUCTOR
 
@@ -123,7 +125,7 @@ C<@items>.
 
 =head2 items
 
-    my @items = $address_list->items();
+    my @items = $address_list->items;
 
 Gets the items of the address list.
 
@@ -139,8 +141,9 @@ Appends items to the address list.
 
 Returns the formatted address list string for use in a message header.
 
-$encoder is an optional L<Email::MIME::RFC2047::Encoder> object used for
-encoding display names with non-ASCII characters.
+C<$encoder> is an optional L<Email::MIME::RFC2047::Encoder> object used for
+encoding display names with non-ASCII characters. If it isn't provided, a
+default UTF-8 encoder will be used.
 
 =head1 AUTHOR
 
