@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::Group;
-$Email::MIME::RFC2047::Group::VERSION = '0.94';
+$Email::MIME::RFC2047::Group::VERSION = '0.95';
 use strict;
 use warnings;
 
@@ -25,45 +25,44 @@ sub new {
     return bless($self, $class);
 }
 
-# unused
-sub _parse {
-    my ($class, $string, $decoder) = @_;
-    my $string_ref = ref($string) ? $string : \$string;
-
-    $decoder ||= Email::MIME::RFC2047::Decoder->new();
-
-    my $name = $decoder->decode_phrase($string_ref);
-    return $class->_parse_error($string_ref, 'group name')
-        if $name eq '';
-
-    $$string_ref =~ /\G:/cg
-        or return $class->_parse_error($string_ref, 'group');
-
-    my $mailbox_list;
-
-    if ($$string_ref =~ /\G\s*;\s*/cg) {
-        $mailbox_list = Email::MIME::RFC2047::MailboxList->new();
-    }
-    else {
-        $mailbox_list = Email::MIME::RFC2047::MailboxList->parse(
-            $string_ref, $decoder
-        );
-
-        $$string_ref =~ /\G;\s*/cg
-            or return $class->_parse_error($string_ref, 'group');
-    }
-
-    my $group = $class->new(
-        name         => $name,
-        mailbox_list => $mailbox_list,
-    );
-
-    if (!ref($string) && pos($string) < length($string)) {
-        return $class->_parse_error($string_ref);
-    }
-
-    return $group;
-}
+#sub _parse {
+#    my ($class, $string, $decoder) = @_;
+#    my $string_ref = ref($string) ? $string : \$string;
+#
+#    $decoder ||= Email::MIME::RFC2047::Decoder->new();
+#
+#    my $name = $decoder->decode_phrase($string_ref);
+#    return $class->_parse_error($string_ref, 'group name')
+#        if $name eq '';
+#
+#    $$string_ref =~ /\G:/cg
+#        or return $class->_parse_error($string_ref, 'group');
+#
+#    my $mailbox_list;
+#
+#    if ($$string_ref =~ /\G\s*;\s*/cg) {
+#        $mailbox_list = Email::MIME::RFC2047::MailboxList->new();
+#    }
+#    else {
+#        $mailbox_list = Email::MIME::RFC2047::MailboxList->parse(
+#            $string_ref, $decoder
+#        );
+#
+#        $$string_ref =~ /\G;\s*/cg
+#            or return $class->_parse_error($string_ref, 'group');
+#    }
+#
+#    my $group = $class->new(
+#        name         => $name,
+#        mailbox_list => $mailbox_list,
+#    );
+#
+#    if (!ref($string) && pos($string) < length($string)) {
+#        return $class->_parse_error($string_ref);
+#    }
+#
+#    return $group;
+#}
 
 sub name {
     my $self = shift;
@@ -114,15 +113,19 @@ Email::MIME::RFC2047::Group - Handling of MIME encoded mailbox groups
 
 =head1 VERSION
 
-version 0.94
+version 0.95
 
 =head1 SYNOPSIS
 
     use Email::MIME::RFC2047::Group;
 
+    my $group = Email::MIME::RFC2047::Group->parse($string);
+    print $group->name, "\n";
+    my @mailboxes = $group->mailbox_list->items;
+
     my $group = Email::MIME::RFC2047::Group->new(
-       name => $name,
-       mailbox_list => $mailbox_list,
+        name         => $name,
+        mailbox_list => $mailbox_list,
     );
     $email->header_set('To', $group->format());
 
@@ -135,8 +138,8 @@ This module handles RFC 2822 C<group>s.
 =head2 new
 
     my $group = Email::MIME::RFC2047::Group->new(
-       name => $name,
-       mailbox_list => $mailbox_list,
+        name         => $name,
+        mailbox_list => $mailbox_list,
     );
 
 Creates a new Email::MIME::RFC2047::Group object, optionally with a
@@ -146,14 +149,14 @@ display name C<$name> and an mailbox list C<$mailbox_list>.
 
 =head2 name
 
-    my $name = $group->name();
+    my $name = $group->name;
     $group->name($new_name);
 
 Gets or sets the display name of the group.
 
 =head2 mailbox_list
 
-    my $mailbox_list = $group->mailbox_list();
+    my $mailbox_list = $group->mailbox_list;
     $group->mailbox_list($new_mailbox_list);
 
 Gets or sets the mailbox list of the group.
@@ -165,7 +168,8 @@ Gets or sets the mailbox list of the group.
 Returns the formatted string for use in a message header.
 
 C<$encoder> is an optional L<Email::MIME::RFC2047::Encoder> object used for
-encoding display names with non-ASCII characters.
+encoding display names with non-ASCII characters. If it isn't provided, a
+default UTF-8 encoder is used.
 
 =head1 AUTHOR
 
