@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::MailboxList;
-$Email::MIME::RFC2047::MailboxList::VERSION = '0.94';
+$Email::MIME::RFC2047::MailboxList::VERSION = '0.95';
 use strict;
 use warnings;
 
@@ -31,14 +31,14 @@ Email::MIME::RFC2047::MailboxList - Handling of MIME encoded mailbox lists
 
 =head1 VERSION
 
-version 0.94
+version 0.95
 
 =head1 SYNOPSIS
 
     use Email::MIME::RFC2047::MailboxList;
 
     my $mailbox_list = Email::MIME::RFC2047::MailboxList->parse($string);
-    my @items = $mailbox_list->items();
+    my @items = $mailbox_list->items;
 
     my $mailbox_list = Email::MIME::RFC2047::MailboxList->new();
     $mailbox_list->push($mailbox);
